{ lib, pkgs, ... }:
{
  # List services that you want to enable:
  services = {
    xserver = {
      layout = "be";
      xkbVariant = "nodeadkeys";
      videoDrivers = ["nvidia"];
      exportConfiguration = true;

      #displayManager.gdm.enable = true;
    };

    gnome.gnome-keyring.enable = true;

    spice-vdagentd.enable = true;
    gvfs = {
      enable = true;
      package = lib.mkForce pkgs.gnome3.gvfs;
    };

    pipewire = {
      enable = true;
      alsa.enable = true;
      alsa.support32Bit = true;
      pulse.enable = true;
      jack.enable = true;
    };
    udev.packages = with pkgs; [
      via
    ];
    printing = {
      enable = true;
      drivers = with pkgs; [
        gutenprint
        hplip
      ];
    };
  };
  xdg.portal = {
    enable = true;
    wlr.enable = true;
    extraPortals = [ 
      #pkgs.xdg-desktop-portal-hyprland
      pkgs.xdg-desktop-portal-gtk
      pkgs.xdg-desktop-portal-wlr
    ];
  };
  virtualisation = {
    docker.enable = true;
    docker.rootless = {
      enable = true;
      setSocketVariable = true;
    };
    spiceUSBRedirection.enable = true;
    libvirtd = {
      enable = true;
      allowedBridges = ["wlo1"];
      qemu = {
        swtpm.enable = true;
        ovmf.enable = true;
        ovmf.packages = [ pkgs.OVMFFull.fd ];
      };
    };
  };
  security = {
    rtkit.enable = true;
    pam.services.swaylock = { #Swaylock fix for wrong password
      text = ''
        auth include login
      '';
    };
  };
}